==> tdesktop-4.3.0-full.tar.gz: tdesktop-4.3.0-full/Telegram/lib_ui/ui/style/style_core_scale.h <==
// This file is part of Desktop App Toolkit,
// a set of libraries for developing nice desktop applications.
//
// For license and copyright information please follow this link:
// https://github.com/desktop-app/legal/blob/master/LEGAL
//
#pragma once

#include "base/algorithm.h"

#include <QtCore/QSize>

#include <algorithm>
#include <cmath>

namespace style {

inline constexpr auto kScaleAuto = 0;
inline constexpr auto kScaleMin = 50;
inline constexpr auto kScaleDefault = 100;
inline constexpr auto kScaleMax = 300;

[[nodiscard]] int DevicePixelRatio();
void SetDevicePixelRatio(int ratio);

[[nodiscard]] int Scale();
void SetScale(int scale);

[[nodiscard]] inline int CheckScale(int scale) {
	return (scale == kScaleAuto)
		? kScaleAuto
		: std::clamp(scale, kScaleMin, kScaleMax / DevicePixelRatio());
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value, int scale) {
	if (value < 0.) {
		return -ConvertScale(-value, scale);
	}
	const auto result = T(base::SafeRound(
		(double(value) * scale / 100.) - 0.01));
	return (!std::is_integral_v<T> || !value || result) ? result : 1;
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value) {
	return ConvertScale(value, Scale());
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value, int scale) {
	return (value < 0.)
		? (-ConvertScale(-value, scale))
		: T(double(value) * scale / 100.);
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value) {
	return ConvertScaleExact(value, Scale());
}

[[nodiscard]] inline QSize ConvertScale(QSize size) {
	return QSize(ConvertScale(size.width()), ConvertScale(size.height()));
}

} // namespace style

==> tdesktop-5.8.3-full.tar.gz: tdesktop-5.8.3-full/Telegram/lib_ui/ui/style/style_core_scale.h <==
// This file is part of Desktop App Toolkit,
// a set of libraries for developing nice desktop applications.
//
// For license and copyright information please follow this link:
// https://github.com/desktop-app/legal/blob/master/LEGAL
//
#pragma once

#include "base/algorithm.h"
#include "base/assertion.h"

#include <QtCore/QSize>

#include <algorithm>
#include <cmath>

namespace style {

inline constexpr auto kScaleAuto = 0;
inline constexpr auto kScaleMin = 50;
inline constexpr auto kScaleDefault = 100;
inline constexpr auto kScaleMax = 300;
inline constexpr auto kScaleAlwaysAllowMax = 200;

[[nodiscard]] int DevicePixelRatio();
void SetDevicePixelRatio(int ratio);

[[nodiscard]] int Scale();
void SetScale(int scale);

[[nodiscard]] int MaxScaleForRatio(int ratio);
[[nodiscard]] int CheckScale(int scale);

template <typename T>
[[nodiscard]] inline T ConvertScale(T value, int scale) {
	if (value < 0.) {
		Assert(!(T(-value) < 0.)); // T = int, value = INT_MIN.
		return -ConvertScale(-value, scale);
	}
	const auto result = T(base::SafeRound(
		(double(value) * scale / 100.) - 0.01));
	return (!std::is_integral_v<T> || !value || result) ? result : 1;
}

template <typename T>
[[nodiscard]] inline T ConvertScale(T value) {
	return ConvertScale(value, Scale());
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value, int scale) {
	return (value < 0.)
		? (-ConvertScale(-value, scale))
		: T(double(value) * scale / 100.);
}

template <typename T>
[[nodiscard]] inline T ConvertScaleExact(T value) {
	return ConvertScaleExact(value, Scale());
}

[[nodiscard]] inline QSize ConvertScale(QSize size) {
	return QSize(ConvertScale(size.width()), ConvertScale(size.height()));
}

[[nodiscard]] inline float64 ConvertFloatScale(float64 value) {
	constexpr auto kPrecision = 1000000.;
	return ConvertScale(value * kPrecision) / kPrecision;
}

} // namespace style
